selectTau_uniform_exact: Exact Uniform Sampler of Feasible Changepoints

View source: R/gareg_knots.R

selectTau_uniform_exactR Documentation

Exact Uniform Sampler of Feasible Changepoints

Description

Samples m ordered changepoint indices uniformly from all feasible configurations on 1:N subject to a minimum spacing minDist. Encodes the result as a chromosome for downstream GA operators.

Usage

selectTau_uniform_exact(N, m, minDist, lmax)

Arguments

N

Integer series length.

m

Integer number of changepoints to place.

minDist

Integer minimum spacing between adjacent changepoints.

lmax

Integer chromosome length.

Value

Integer vector length lmax: c(m, tau_1, ..., tau_m, N+1, 0, 0, ...).

See Also

Popinitial_fixknots, mutation_fixknots


GAReg documentation built on March 29, 2026, 5:08 p.m.