| selectTau_uniform_exact | R Documentation |
Samples m ordered changepoint indices uniformly from all feasible
configurations on 1:N subject to a minimum spacing minDist.
Encodes the result as a chromosome for downstream GA operators.
selectTau_uniform_exact(N, m, minDist, lmax)
N |
Integer series length. |
m |
Integer number of changepoints to place. |
minDist |
Integer minimum spacing between adjacent changepoints. |
lmax |
Integer chromosome length. |
Integer vector length lmax:
c(m, tau_1, ..., tau_m, N+1, 0, 0, ...).
Popinitial_fixknots, mutation_fixknots
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.